<?php

/*
Plugin Name: WP Wall
Version: 0.8.2
Description: "Wall" widget that appears in your blog's side bar. Readers can add a quick comment about the blog as a whole, and the comment will appear in the sidebar immediately (without reloading the page)
Author: Vladimir Prelovac
Author URI: http://www.prelovac.com/vladimir
Plugin URI: http://www.prelovac.com/vladimir/wordpress-plugins/wp-wall
*/

/*  
Copyright 2008  Vladimir Prelovac  (email : vprelovac@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// todo
// add email and website?
// parse links in comments to make them clickable?


global $wp_version;	

$exit_msg='WP Wall requires WordPress 2.3 or newer. <a href="http://codex.wordpress.org/Upgrading_WordPress">Please update!</a>';

if (version_compare($wp_version,"2.3","<"))
{
	exit ($exit_msg);
}

$wp_wall_plugin_url = trailingslashit( get_bloginfo('wpurl') ).PLUGINDIR.'/'. dirname( plugin_basename(__FILE__) );

function WPWall_WidgetControl() {
	
	// get saved options
	$options = WPWall_GetOptions();
	
	// handle user input
	if ( $_POST["wall_submit"] ) {
		$options['wall_title'] = strip_tags( stripslashes( $_POST["wall_title"] ) );
		
		update_option('wp_wall', $options);
	}
	
	$title = $options['wall_title'];
	
	// print out the widget control		
	include('wp-wall-widget-control.php');
}


function WPWall_Widget($args = array() ) {	
	
	global  $user_ID,  $user_identity, $wp_wall_plugin_url, $wpdb;		
	
	// extract the parameters
	extract($args);
	
	// get our options
	$options=WPWall_GetOptions();	

	extract($options);
	
	if (!empty($latest))
	{
		// get comments from WordPress database	
		$comments = $wpdb->get_results("
												SELECT comment_date
												FROM $wpdb->comments 
												WHERE comment_approved = '1' AND comment_post_ID=$pageId AND NOT (comment_type = 'pingback' OR comment_type = 'trackback')
												ORDER BY comment_date_gmt DESC 	LIMIT 1
											");		
		if ($comments)
			$latest_comment=date($latest, strtotime($comments[0]->comment_date));
		
	}
	

	
	// include our widget
	include('wp-wall-widget.php');
	
		
}

function WPWall_Init() {

	// register widget
	register_sidebar_widget('WP Wall', 'WPWall_Widget');	

	// alternative way
	//$widget_options = array('classname' => 'WPWall_Widget', 'description' => "A comment 'Wall' for your sidebar." );
  //wp_register_sidebar_widget('WP Wall', 'WP Wall', 'WPWall_Widget', $widget_options);

	// register widget control
	register_widget_control('WP Wall', 'WPWall_WidgetControl');

	$options = WPWall_GetOptions();
	
	// get our wall pageId
	$pageId=$options['pageId'];
	
	// check if the actual post exists
	$actual_post=get_post($pageId);
	
	// check if the page is already created	
	if (!$pageId || !$actual_post || ($pageId!=$actual_post->ID) )
	{
		// create the page and save it's ID
		$options['pageId']=	WPWall_CreatePage();
		
		update_option('wp_wall', $options);
	}			
}

add_action('init', 'WPWall_Init');

function WPWall_CreatePage() {

	// create post object
	class mypost {
		var $post_title;
		var $post_content;
		var $post_status; // draft, published 
		var $post_type; // can be 'page' or 'post' 
		var $comment_status; // open or closed for commenting
	}
	
	// initialize the post object
	$mypost = new mypost();
	
	// fill it with data
	$mypost->post_title = 'WP Wall Guestbook';
	$mypost->post_content =  "This is a placeholder page for your WP Wall. Deleting tis page will make all you comment dissapear (new one will be recreated). You may publish this page createa a sort of a guestbook and an archive of all wall comments..";
	$mypost->post_status = 'draft';
	$mypost->post_type = 'page';
	$mypost->comment_status = 'open';
	
	// insert the post and return it's ID
	return wp_insert_post($mypost);
}

add_action('wp_head', 'WPWall_HeadAction' );

function WPWall_HeadAction()
{
	global $wp_wall_plugin_url;
	
	echo '<link rel="stylesheet" href="'.$wp_wall_plugin_url.'/wp-wall.css" type="text/css" />'; 
}

add_action('wp_print_scripts', 'WPWall_ScriptsAction');

function WPWall_ScriptsAction() 
{
	global $wp_wall_plugin_url;
	
	wp_enqueue_script('jquery');
	wp_enqueue_script('jquery-form');
	wp_enqueue_script('wp_wall_script', $wp_wall_plugin_url.'/wp-wall.js.php', array('jquery', 'jquery-form')); 
}

function WPWall_ShowComments($page = 1) {
	global $wpdb, $wp_wall_plugin_url;

	// get our page id	
	$options = WPWall_GetOptions();					
	$pageId=$options['pageId'];	
	
	// number of comments to display
	if ( !$number = (int) $options['wall_comments'] )
		$number = 5;
	else if ( $number < 1 )
		$number = 1;
	else if ( $number > 25 )
		$number = 25;
	
	$result='';


	// get comments from WordPress database	
	$comments = $wpdb->get_results("
											SELECT *
											FROM $wpdb->comments 
											WHERE comment_approved = '1' AND comment_post_ID=$pageId AND NOT (comment_type = 'pingback' OR comment_type = 'trackback')
											ORDER BY comment_date_gmt DESC 										
										");		
	
	
	if (count($comments) > $number)
	{
			$nav=1;
			$pages=ceil(count($comments)/$number);
	}
	else {
		$nav=0;
		$pages=0;
	}
	
		
	$getnumber=$number*$page;
										
	// get comments from WordPress database	
	$comments = $wpdb->get_results("
											SELECT *
											FROM $wpdb->comments 
											WHERE comment_approved = '1' AND comment_post_ID=$pageId AND NOT (comment_type = 'pingback' OR comment_type = 'trackback')
											ORDER BY comment_date_gmt DESC 
											LIMIT $getnumber
										");										
	
	
	$comments=array_slice($comments, $getnumber-$number, $number);
	if ( $comments ) {  
	
		$count=1;
		$oddcomment='';
		// display comments one by one
		foreach ($comments as $comment) {			
			//$comment->comment_content = convert_smilies(WPWall_GetExcerpt($comment->comment_content, $options['wall_wrap'])); ($comment->comment_content);//apply_filters('convert_smilies', $comment->comment_content );
			if ( current_user_can( 'edit_post', $comment->comment_post_ID ) ) 
				$deleteurl= '<a href="javascript:verify(\''.clean_url( wp_nonce_url(get_bloginfo('wpurl')."/wp-admin/comment.php?action=deletecomment".( $options['delete_spam'] ? "&dt=spam" : "")."&p=$comment->comment_post_ID&c=$comment->comment_ID", "delete-comment_$comment->comment_ID" ) ).'\', \'\')">'.htmlspecialchars  ($comment->comment_author).'</a>'; 
			else
				$deleteurl=htmlspecialchars  ($comment->comment_author);
		
			$result.= '<p class="wall-'.$count.$oddcomment.'"><span class="wallauthor" title="'.htmlspecialchars($comment->comment_author).' on '.$comment->comment_date.'" >' . $deleteurl.'</span><span class="wallcomment" title="'.htmlspecialchars($comment->comment_content).'" >: '.convert_smilies(htmlspecialchars(WPWall_GetExcerpt($comment->comment_content, $options['wall_wrap']))).'</span></p>';
			$count++;
			if ($oddcomment == ' wall-alt') $oddcomment = '';
			else $oddcomment = ' wall-alt';

		}			
	}
		
		$result.='<input type="hidden" name="page" id="page" value="'.$page.'" />';
		
		$result.='<input type="hidden" name="page_left" id="page_left" value="'.(($page > 1) ? ($page-1) : $page).'" />';

		$result.='<input type="hidden" name="page_right" id="page_right" value="'.(($page < $pages) ? ($page+1) : $page).'" />';
		

	return $result;
}

function WPWall_GetOptions()
{
	
 $options = array(
	 'wall_title' => 'Wall',
	 'wall_reply' => 'Leave a reply',
	 'wall_comments' => 5,
	 'wall_wrap' => 25,
	 'disable_new' => '',
	 'only_registered' => '', 
	 'refresh_time' => 0,
	 'rss_feed' => '', 
	 'pageId' => '', 
	 'delete_spam' => '', 
	 'show_all' => '',
	 'latest' => 'D, H:i'
	 );
  
 $saved = get_option('wp_wall');
 
 
 if (!empty($saved)) {
	 foreach ($saved as $key => $option)
 			$options[$key] = $option;
 }
	
 if ($saved != $options)	
 	update_option('wp_wall', $options);
 	
 return $options;
}

add_action('admin_menu', 'WPWall_AdminMenu');

	// Hook the options mage
function WPWall_AdminMenu() {
	add_options_page('WP Wall Options', 'WP Wall ', 8, basename(__FILE__),'WPWall_Options');	
} 


function WPWall_Options()
{
	global $wp_wall_plugin_url;
	$options = WPWall_GetOptions();
	
	if ( isset($_POST['submitted']) ) {
		
		//print_r($_POST);
			
		$options['disable_new']=$_POST['disable_new'];					
		$options['only_registered']=$_POST['only_registered'];		
		$options['wall_title']=strip_tags( stripslashes($_POST['wall_title']));		
		$options['wall_reply']=strip_tags( stripslashes($_POST['wall_reply']));		
		$options['wall_comments']=(int) ($_POST['wall_comments']);		
		$options['wall_wrap']=(int) ($_POST['wall_wrap']);	
		$options['refresh_time']=(int) ($_POST['refresh_time']);
		$options['rss_feed']=$_POST['rss_feed'];							
		$options['delete_spam']=$_POST['delete_spam'];	
		$options['show_all']=$_POST['show_all'];	
		$options['latest']=trim($_POST['latest']);	
		
	
		update_option('wp_wall', $options);
		echo '<div class="updated fade"><p>Plugin settings saved.</p></div>';
	}

	
	$action_url = $_SERVER['REQUEST_URI'];	

	$disable_new=$options['disable_new']=='on'?'checked':'';
	$only_registered=$options['only_registered']=='on'?'checked':'';
	$rss_feed=$options['rss_feed']=='on'?'checked':'';
	$delete_spam=$options['delete_spam']=='on'?'checked':'';
	$show_all=$options['show_all']=='on'?'checked':'';
	
	$wall_title=$options['wall_title'];
	$wall_comments=$options['wall_comments'];
	$wall_reply=$options['wall_reply'];
	$wall_wrap=$options['wall_wrap'];
	$refresh_time=$options['refresh_time'];
	$latest=$options['latest'];
	
	$pageId=$options['pageId'];
			
	$imgpath=$wp_wall_plugin_url.'/i';	
	
	echo <<<END

<div class="wrap" style="max-width:950px !important;">
	<h2>WP Wall</h2>
				
	<div id="poststuff" style="margin-top:10px;">
	
	<div id="sideblock" style="float:right;width:220px;margin-left:10px;"> 
		 <h3>Information</h3>
		 <div id="dbx-content" style="text-decoration:none;">
			 <img src="$imgpath/home.png"><a style="text-decoration:none;" href="http://www.prelovac.com/vladimir/wordpress-plugins/wp-wall"> WP Wall Home</a><br /><br />
			 <img src="$imgpath/help.png"><a style="text-decoration:none;" href="http://www.prelovac.com/vladimir/wordpress-plugins/wp-wall#comments"> Suggest a Feature</a><br /><br />
			 <img src="$imgpath/rate.png"><a style="text-decoration:none;" href="http://wordpress.org/extend/plugins/wp-wall/"> Rate WP Wall</a><br /><br />
			 <img src="$imgpath/more.png"><a style="text-decoration:none;" href="http://www.prelovac.com/vladimir/wordpress-plugins"> My WordPress Plugins</a><br /><br />
			 <br />
		
			 <p align="center">
			 <img src="$imgpath/p1.png"></p>
			
			 <p> <img src="$imgpath/idea.png"><a style="text-decoration:none;" href="http://www.prelovac.com/vladimir/services"> Need a WordPress Expert?</a></p>
 		</div>
 	</div>
	
	 <div id="mainblock" style="width:710px">
	 
		<div class="dbx-content">
		 	<form name="wpwallform" action="$action_url" method="post">
					<input type="hidden" name="submitted" value="1" /> 
					<h3> General Options</h3>
					
					<p>WP Wall allows you to have a comments 'wall' on your blog.</p>
						
					
					<input type="text" name="wall_title" size="15" value="$wall_title"/>
					<label for="wall_title">Title for the widget</label> <br /><br />			
					
					<input type="text" name="wall_reply" size="15" value="$wall_reply"/>
					<label for="wall_reply">Leave a reply text</label> <br /><br />	
									
					<input type="text" name="wall_comments" size="15" value="$wall_comments"/>
					<label for="wall_comments">Number of comments to show (max 25)</label> <br /><br />								
					
					<input type="checkbox" name="show_all"  $show_all/><label for="show_all"> Show All link - you need to publish your Wall page (<a href="page.php?action=edit&post=$pageId">go there</a>)</label>  <br />
					
					<h4>Comments</h3>
					<input type="checkbox" name="disable_new"  $disable_new/><label for="disable_new"> Disable new comments</label>  <br />
					<input type="checkbox" name="only_registered"  $only_registered/><label for="only_registered"> Only registered users can post</label> <br />
					<input type="checkbox" name="delete_spam"  $delete_spam/><label for="delete_spam"> Treat admin deleted comments as spam</label> <br /> <br/>
					<input type="text" name="latest" size="15" value="$latest"/>
					<label for="latest">If you wish to show time of latest comment, type in <a href="http://www.php.net/date">date format</a>. D, H:i will do for start.</label> <br /><br />			
					
					<h4>RSS Feed</h4>
					
					<input type="checkbox" name="rss_feed"  $rss_feed/><label for="rss_feed"> Show Wall's RSS feed link</label> <br />
					
					<br />
					<h3>Interactive Wall</h3>	
					<p>You may specify a refresh time in seconds for automatic (Ajax) reload of the Wall.</p><p>Set to 0 to turn this feature off.</p>
					
					<input type="text" name="refresh_time" size="15" value="$refresh_time"/>
					<label for="refresh_time">Refresh time</label>  <br />
					
					<br />					
				
					
					
		
		<br/><br/><h3>Appearance</h3>	
		<p>You can style the look of your Wall by editing wp-wall.css file of the plugin. Be sure to make backup if you upgrade to newer version. </p>
		
		<h4>Smilies</h4>
		WP Wall can show smilies using built in WordPress functionality if you enable it in your administration panel (Settings-> Writing-> Convert emoticons...). You can find more information about using smilies <a href="http://codex.wordpress.org/Using_Smilies">here</a>.
		
		<h4>Excerpts</h4>
		If comments are too long you can choose to display a comment excerpt instead. The whole comment is still available when the user hovers the mouse over it (tooltip).</p>
		Set to 0 to turn off this feature. Default is 25.</p> <br /> <br />
		
		<input type="text" name="wall_wrap" size="15" value="$wall_wrap"/>
		<label for="wall_wrap">Show excerpt word count</label> <br /><br />		
	
		<div class="submit"><input type="submit" name="Submit" value="Update options" /></div>
			</form>
		</div>
					
		<br/><br/><h3>&nbsp;</h3>	
	 </div>

	</div>
	
<h5>WordPress plugin by <a href="http://www.prelovac.com/vladimir/">Vladimir Prelovac</a></h5>
</div>
END;
}

function WPWall_GetExcerpt($text, $length = 25)
{
		if (!$length)
			return $text;
			
		$text = strip_tags($text);		
		$words = explode(' ', $text, $length + 1);
		if (count($words) > $length) {
			array_pop($words);
			array_push($words, '[...]');
			$text = implode(' ', $words);
		}	
		return $text;
}
?>